stallings_graphs: Stallings graph representation of finitely generated subgroups of free groups
===============================================================================================

Description
-----------

Stallings graph representation of finitely generated subgroups of free groups

License
-------

GPLv2+

Upstream Contact
----------------

- https://pypi.org/project/stallings-graphs/
- https://github.com/passagemath/passagemath-pkg-stallings_graphs
